/*
 * timer0.c : make 1msec tick by timer0
 *   by uratan! 2008.9.5
 */
#include "common.h"
#include "LPC214x.h"
#include "irq.h"

/*
 * functions
 */
int timer0_init(void);
void timer0_run(void);
void timer0_stop(void);
static void timer0_handler(void) __attribute__ ((interrupt("IRQ")));

/*
 * valiables
 */
volatile int timer0_tick;

/*
 *
 */
int timer0_init(void)
{
	timer0_tick = FALSE;

	T0TCR = 2;					/* once stop & reset the timer */

	if(install_irq(TIMER0_INT, (void *)timer0_handler) == FALSE) {
		return(FALSE);
	}

	T0PR = Fpclk/1000000 - 1;	/* set pre-scale divider for 1MHz */
	T0MR0 = 1000 - 1;			/* set default match value: 1msec */
	T0MCR = 3;					/* 'interrupt and reset' when MR0 */

	return(TRUE);
}

/*
 *
 */
void timer0_run(void)
{
	T0TCR = 1;

	return;
}

/*
 *
 */
void timer0_stop(void)
{
	T0TCR = 0;
	return;
}

/*
 *
 */
static void timer0_handler(void)
{
	T0IR = 1;				/* clear interrupt flag */

	timer0_tick = TRUE;

	VICVectAddr = 0;		/* Acknowledge Interrupt */
}
